<?php
/**
 * Display links to active Xtreme One Child settings' pages
 *
 * @package    Xtreme One Toolbar
 * @subpackage Theme Support
 * @author     David Decker - DECKERWEB
 * @copyright  Copyright 2012, David Decker - DECKERWEB
 * @license    http://www.opensource.org/licenses/gpl-license.php GPL v2.0 (or later)
 * @link       http://genesisthemes.de/en/wp-plugins/xtreme-one-toolbar/
 * @link       http://twitter.com/#!/deckerweb
 *
 * @since 1.1
 */

/**
 * Setting default values for some variables
 *
 * @since 1.1
 */
$xotb_is_xochild = 'default';
$xtreme_child_name = 'default';
$xtreme_child_forum = 'default';


/**
 * "Theme Settings" String for all Child Themes
 *
 * @since 1.1
 *
 * @param $xotb_theme
 * @param $xotb_theme_fallback
 */
$xotb_theme = '&nbsp;' . __( 'Theme', 'xtreme-one-toolbar' );
$xotb_theme_fallback = __( 'Theme', 'xtreme-one-toolbar' ) . ':&nbsp;';


/**
 * Display links to official Xtreme One Child theme settings pages
 *
 * @since 1.1
 *
 * @param $xotb_is_xochild
 * @param $xochild_aurl
 * @param $xtreme_child_name
 * @param $xtreme_child_forum
 * @param $xotb_stylesheet_name
 */
	/** Default Admin URL for Third-Party Child Theme Settings */
	$xochild_aurl = admin_url( 'themes.php?page=xtreme_backend' );

	/** Check for Themedy or ThesisThemes Child Theme name */
		// Xtreme Blank (packaged)
	if ( $xotb_stylesheet_name == 'Xtreme Blank Child Theme' ) {
		$xotb_is_xochild = 'xochild_yes';
		$xtreme_child_name = 'Blank' . $xotb_theme;
		$xtreme_child_forum = $xo_url_support;

		// Xtreme Minimalist (premium)
	} elseif ( $xotb_stylesheet_name == 'Xtreme Minimalist' ) {
		$xotb_is_xochild = 'xochild_yes';
		$xtreme_child_name = 'Minimalist' . $xotb_theme;
		$xtreme_child_forum = $xo_url_support;

		// Xtreme Indoor (premium)
	} elseif ( $xotb_stylesheet_name == 'Xtreme Indoor' ) {
		$xotb_is_xochild = 'xochild_yes';
		$xtreme_child_name = 'Indoor' . $xotb_theme;
		$xtreme_child_forum = $xo_url_support;

		// Xtreme VintageFolio (premium)
	} elseif ( $xotb_stylesheet_name == 'Xtreme VintageFolio' || $xotb_stylesheet_name == 'Xtreme WorkFolio' ) {
		$xotb_is_xochild = 'xochild_yes';
		$xtreme_child_name = 'VintageFolio' . $xotb_theme;
		$xtreme_child_forum = $xo_url_support;

		// Xtreme Tuscany (premium)
	} elseif ( $xotb_stylesheet_name == 'Xtreme Tuscany' ) {
		$xotb_is_xochild = 'xochild_yes';
		$xtreme_child_name = 'Tuscany' . $xotb_theme;
		$xtreme_child_forum = $xo_url_support;

		// Xtreme Draft (premium)
	} elseif ( $xotb_stylesheet_name == 'Xtreme Draft' ) {
		$xotb_is_xochild = 'xochild_yes';
		$xtreme_child_name = 'Draft' . $xotb_theme;
		$xtreme_child_forum = $xo_url_support;

	} else {

		// Simple fallback for any other child theme (name)
		$xotb_is_xochild = 'xochild_yes';
		$xtreme_child_name = $xotb_theme_fallback . $xotb_stylesheet_name;

	}  // end-if Xtreme Child name check


	/** Official Child Themes - display links */
	if ( $xotb_is_xochild == 'xochild_yes' && current_user_can( 'manage_options' ) ) {

		/** "Theme Group" menu items */
		$menu_items['xochildsettings'] = array(
			'parent' => $tgroup,
			'title'  => $xtreme_child_name,
			'href'   => $xochild_aurl,
			'meta'   => array( 'target' => '', 'title' => $xtreme_child_name )
		);

		/** Check for custom menus support */
		if ( current_theme_supports( 'menus' ) && current_user_can( 'edit_theme_options' ) ) {
			$menu_items['xochild-menus'] = array(
				'parent' => $xochildsettings,
				'title'  => __( 'Custom Menus', 'xtreme-one-toolbar' ),
				'href'   => admin_url( 'nav-menus.php' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Custom Menus', 'xtreme-one-toolbar' ) )
			);
		}  // end-if custom menus

		/** Check for custom background support */
		if ( current_theme_supports( 'custom-background' ) && current_user_can( 'edit_theme_options' ) ) {
			$menu_items['xochild-background'] = array(
				'parent' => $xochildsettings,
				'title'  => __( 'Custom Background', 'xtreme-one-toolbar' ),
				'href'   => admin_url( 'themes.php?page=custom-background' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Custom Background', 'xtreme-one-toolbar' ) )
			);
		}  // end-if custom background

		/** Check for custom header support */
		if ( current_theme_supports( 'custom-header' ) && current_user_can( 'edit_theme_options' ) ) {
			$menu_items['xochild-header'] = array(
				'parent' => $xochildsettings,
				'title'  => __( 'Custom Header', 'xtreme-one-toolbar' ),
				'href'   => admin_url( 'themes.php?page=custom-header' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Custom Header', 'xtreme-one-toolbar' ) )
			);
		}  // end-if custom header

		/** Display theme editor links for proper caps */
		if ( !( defined( 'DISALLOW_FILE_EDIT' ) && DISALLOW_FILE_EDIT ) && current_user_can( 'edit_themes' ) ) {

			/** Include plugin file with seo plugin support links */
			require_once( XOTB_PLUGIN_DIR . '/includes/xotb-editfiles.php' );

		}  // end-if theme editor check

		/** Child Support Forum */
		if ( $xtreme_child_forum !== 'default' ) {
			$menu_items['xochild-support'] = array(
				'parent' => $xochildsettings,
				'title'  => __( 'Support Forum', 'xtreme-one-toolbar' ),
				'href'   => $xtreme_child_forum,
				'meta'   => array( 'title' => __( 'Support Forum for Child Theme', 'xtreme-one-toolbar' ) )
			);
		}  // end-if support forum check

	}  // end-if display links

/** End Official Child Themes */
