<?php 
/**
 * Main plugin file. This plugin adds useful admin links and resources for the Xtreme One Framework to the WordPress Toolbar / Admin Bar.
 *
 * @package   Xtreme One Toolbar
 * @author    David Decker
 * @link      http://twitter.com/#!/deckerweb
 * @copyright Copyright 2012, David Decker - DECKERWEB
 *
 * @credits Inspired and based on the plugin "WooThemes Admin Bar Addition" by Remkus de Vries @defries.
 * @link    http://remkusdevries.com/
 * @link    http://twitter.com/#!/defries
 *
 * Plugin Name: Xtreme One Toolbar
 * Plugin URI: http://genesisthemes.de/en/wp-plugins/xtreme-one-toolbar/
 * Description: This plugin adds useful admin links and resources for Xtreme One Framework to the WordPress Toolbar / Admin Bar.
 * Version: 1.1
 * Author: David Decker - DECKERWEB
 * Author URI: http://deckerweb.de/
 * License: GPLv2
 * Text Domain: xtreme-one-toolbar
 * Domain Path: /languages/
 */

/**
 * Setting constants
 *
 * @since 1.0
 * @version 1.1
 */
/** Plugin directory */
define( 'XOTB_PLUGIN_DIR', dirname( __FILE__ ) );

/** Plugin base directory */
define( 'XOTB_PLUGIN_BASEDIR', dirname( plugin_basename( __FILE__ ) ) );


add_action( 'init', 'ddw_xotb_init' );
/**
 * Load the text domain for translation of the plugin.
 * Load admin helper functions - only within 'wp-admin'.
 * 
 * @since 1.0
 * @version 1.1
 */
function ddw_xotb_init() {

	/** First look in WordPress' "languages" folder = custom & update-secure! */
	load_plugin_textdomain( 'xtreme-one-toolbar', false, XOTB_PLUGIN_BASEDIR . '/../../languages/xtreme-one-toolbar/' );

	/** Then look in plugin's "languages" folder = default */
	load_plugin_textdomain( 'xtreme-one-toolbar', false, XOTB_PLUGIN_BASEDIR . '/languages/' );

	/** Include admin helper functions */
	if ( is_admin() ) {
		require_once( XOTB_PLUGIN_DIR . '/includes/xotb-admin.php' );
	}
}


add_action( 'admin_bar_menu', 'ddw_xotb_admin_bar_menu', 98 );
/**
 * Add new menu items to the WordPress Toolbar / Admin Bar.
 * 
 * @since 1.0
 * @version 1.1
 *
 * @global mixed $wp_admin_bar, $stylesheet
 */
function ddw_xotb_admin_bar_menu() {

	global $wp_admin_bar, $stylesheet;

	/**
	 * Allows for filtering the general user role/capability to see main & sub-level items
	 *
	 * Default role: 'manage_options'
	 *
	 * @since 1.1
	 */
	$xotb_filter_capability = apply_filters( 'xotb_filter_capability_all', 'manage_options' );

	/**
	 * Required WordPress cabability to display new admin bar entry
	 * Only showing items if toolbar / admin bar is activated and user is logged in!
	 *
	 * @since 1.0
	 * @version 1.1
	 */
	if ( ! is_user_logged_in() || 
		! is_admin_bar_showing() || 
		! current_user_can( $xotb_filter_capability ) ||  // allows for custom filtering the required role/capability
		defined( 'XOTB_DISPLAY' )  // allows for custom disabling
	)
		return;


	/**
	 * Get current stylesheet name logic - compatible up to WordPress 3.4+!
	 *
	 * @since 1.1
	 *
	 * @param $xotb_stylesheet_name
	 */
	if ( function_exists( 'wp_get_theme' ) ) {			// First, check for WP 3.4+ function wp_get_theme()
		$xotb_stylesheet_name = wp_get_theme( $stylesheet );
	} elseif ( function_exists( 'get_current_theme' ) ) {		// Otherwise fall back to prior WP 3.4 default get_current_theme()
		$xotb_stylesheet_name = get_current_theme();
	} // end-if stylesheet check


	/** Set unique prefix */
	$prefix = 'ddw-xtreme-';
	
	/** Create parent menu item references */
	$xobar = $prefix . 'admin-bar';					// root level
		$xosupport = $prefix . 'xosupport';				// sub level: xo support
		$xocodex = $prefix . 'xocodex';					// sub level: xo codex
			$xocodexcss = $prefix . 'xocodexcss';				// third level: xo codex css
		$xosites = $prefix . 'xosites';					// sub level: xo sites
			$xoaffiliates = $prefix . 'xoaffiliates';			// third level: xo affiliates
		$xosettings = $prefix . 'xosettings';				// sub level: xo settings
		$xolayouts = $prefix . 'xolayouts';				// sub level: xo layouts
		$extgroup = $prefix . 'extgroup';				// sub level: extend group ("hook" place)
			$tgroup = $prefix . 'tgroup';				// sub level: theme group ("hook" place)
				$xochildsettings = $prefix . 'xochildsettings';		// third level theme: xtreme child themes
			$pgroup = $prefix . 'pgroup';				// sub level: plugins group ("hook" place)
				$extensions = $prefix . 'extensions';		// sub level: extensions
					$extwpseosm = $prefix . 'extwpseosm';		// third level plugin: wpseo
					$extyoastseo = $prefix . 'extyoastseo';		// third level plugin: wp seo yoast
					$extseoultimate = $prefix . 'extseoultimate';	// third level plugin: seo ultimate
					$extgdhs = $prefix . 'extgdhs';			// third level plugin: gdheadspace4
		$xogroup = $prefix . 'xogroup';				// sub level: xo group (resources)


	/** Make the "Xtreme (One)" name filterable within menu items */
	$xotb_xtreme_name = apply_filters( 'xotb_filter_xtreme_name', __( 'Xtreme', 'xtreme-one-toolbar' ) );

	/** Make the "Xtreme (One)" name's tooltip filterable within menu items */
	$xotb_xtreme_name_tooltip = apply_filters( 'xotb_filter_xtreme_name_tooltip', _x( 'Xtreme One', 'Translators: For the tooltip', 'xtreme-one-toolbar' ) );


	/** Check for active WP locale version to define links */
		// Links to German pages
	if ( get_locale() == 'de_DE' || get_locale() == 'de_AT' || get_locale() == 'de_CH' || get_locale() == 'de_LU' ) {
		$xo_url_home = 'http://de.xtreme-theme.com/';
		$xo_url_blog = 'http://de.xtreme-theme.com/blog/';
		$xo_url_showcase = 'http://de.xtreme-theme.com/showcase/';
		$xo_url_videos = 'http://de.xtreme-theme.com/videos/';
		$xo_url_themes = 'http://de.xtreme-theme.com/theme/';
		$xo_url_features = 'http://de.xtreme-theme.com/xtreme-one/';
		$xo_url_affiliates = 'http://de.xtreme-theme.com/partnerprogramm/';
		$xo_url_docs = 'http://dokumentation.xtreme-theme.com/';
		$xo_url_hooks = 'http://dokumentation.xtreme-theme.com/hook-referenz/';
		$xo_url_css = 'http://dokumentation.xtreme-theme.com/css/';
		$xo_url_cssyaml = 'http://dokumentation.xtreme-theme.com/css/yaml-modifikationen/';
		$xo_url_knowledge = 'http://wissen.xtreme-theme.com/';
		$xo_url_faq = 'http://de.xtreme-theme.com/faq/';
		$xo_url_support = 'http://support.xtreme-theme.com/forumdisplay.php?f=3';
	}
		// Otherwise load links to English pages	
	else {
		$xo_url_home = 'http://xtreme-theme.com/';
		$xo_url_blog = 'http://xtreme-theme.com/blog/';
		$xo_url_showcase = 'http://xtreme-theme.com/showcase/';
		$xo_url_videos = 'http://xtreme-theme.com/videos/';
		$xo_url_themes = 'http://xtreme-theme.com/theme/';
		$xo_url_features = 'http://xtreme-theme.com/xtreme-one/';
		$xo_url_affiliates = 'http://xtreme-theme.com/affiliates/';
		$xo_url_docs = 'http://documentation.xtreme-theme.com/';
		$xo_url_hooks = 'http://documentation.xtreme-theme.com/hook-references/';
		$xo_url_css = 'http://documentation.xtreme-theme.com/css/';
		$xo_url_cssyaml = 'http://documentation.xtreme-theme.com/css/yaml-modification/';
		$xo_url_knowledge = 'http://knowledgebase.xtreme-theme.com/';
		$xo_url_faq = 'http://xtreme-theme.com/faq/';
		$xo_url_support = 'http://support.xtreme-theme.com/forumdisplay.php?f=15';
	}  // end if else WP locale check

	/** Display these items also when Xtreme One Framework is not installed */
	if ( ! defined( 'XOTB_RESOURCES_DISPLAY' ) ) {
		$xogroup_menu_items = array(

			// Support menu items
			'xosupport' => array(
				'parent' => $xogroup,
				'title'  => __( 'Xtreme One Support', 'xtreme-one-toolbar' ),
				'href'   => $xo_url_support,
				'meta'   => array( 'title' => __( 'Xtreme One Support', 'xtreme-one-toolbar' ) )
			),
			'xosupportsearch' => array(
				'parent' => $xosupport,
				'title'  => __( 'Search Forum', 'xtreme-one-toolbar' ),
				'href'   => 'http://support.xtreme-theme.com/search.php?search_type=1',
				'meta'   => array( 'title' => __( 'Search Forum', 'xtreme-one-toolbar' ) )
			),
			'xosupportsubscribed' => array(
				'parent' => $xosupport,
				'title'  => __( 'My Subscribed Topics', 'xtreme-one-toolbar' ),
				'href'   => 'http://support.xtreme-theme.com/subscription.php',
				'meta'   => array( 'title' => __( 'My Subscribed Topics', 'xtreme-one-toolbar' ) )
			),
			'xosupportnew' => array(
				'parent' => $xosupport,
				'title'  => __( 'New Topics since last visit', 'xtreme-one-toolbar' ),
				'href'   => 'http://support.xtreme-theme.com/search.php?do=getnew&contenttype=vBForum_Post',
				'meta'   => array( 'title' => __( 'New Topics since last visit', 'xtreme-one-toolbar' ) )
			),
			'xosupportnewtoday' => array(
				'parent' => $xosupport,
				'title'  => __( 'New Topics Today', 'xtreme-one-toolbar' ),
				'href'   => 'http://support.xtreme-theme.com/search.php?do=getdaily&contenttype=vBForum_Post',
				'meta'   => array( 'title' => __( 'New Topics Today', 'xtreme-one-toolbar' ) )
			),
			'xosupportuser' => array(
				'parent' => $xosupport,
				'title'  => __( 'User Account at Support Site', 'xtreme-one-toolbar' ),
				'href'   => 'http://support.xtreme-theme.com/usercp.php',
				'meta'   => array( 'title' => __( 'User Account at Support Site', 'xtreme-one-toolbar' ) )
			),
			'xosupportintl' => array(
				'parent' => $xosupport,
				'title'  => __( 'Support Forum International', 'xtreme-one-toolbar' ),
				'href'   => 'http://support.xtreme-theme.com/',
				'meta'   => array( 'title' => __( 'Support Forum International', 'xtreme-one-toolbar' ) )
			),

			// Codex & Documentation menu items
			'xocodex' => array(
				'parent' => $xogroup,
				'title'  => __( 'Codex & Documentation', 'xtreme-one-toolbar' ),
				'href'   => $xo_url_docs,
				'meta'   => array( 'title' => __( 'Codex & Documentation', 'xtreme-one-toolbar' ) )
			),
			'xocodexknowledge' => array(
				'parent' => $xocodex,
				'title'  => __( 'Knowledge Base', 'xtreme-one-toolbar' ),
				'href'   => $xo_url_knowledge,
				'meta'   => array( 'title' => __( 'Knowledge Base', 'xtreme-one-toolbar' ) )
			),
			'xocodexhooks' => array(
				'parent' => $xocodex,
				'title'  => __( 'Hook Reference', 'xtreme-one-toolbar' ),
				'href'   => $xo_url_hooks,
				'meta'   => array( 'title' => __( 'Hook Reference', 'xtreme-one-toolbar' ) )
			),
			'xocodexcss' => array(
				'parent' => $xocodex,
				'title'  => __( 'CSS Structure', 'xtreme-one-toolbar' ),
				'href'   => $xo_url_css,
				'meta'   => array( 'title' => __( 'CSS Structure', 'xtreme-one-toolbar' ) )
			),
			'xocodexcssyaml' => array(
				'parent' => $xocodexcss,
				'title'  => __( 'YAML Modifications', 'xtreme-one-toolbar' ),
				'href'   => $xo_url_cssyaml,
				'meta'   => array( 'title' => __( 'YAML Modifications', 'xtreme-one-toolbar' ) )
			),
			'xocodexfaq' => array(
				'parent' => $xocodex,
				'title'  => __( 'FAQ', 'xtreme-one-toolbar' ),
				'href'   => $xo_url_faq,
				'meta'   => array( 'title' => __( 'FAQ', 'xtreme-one-toolbar' ) )
			),
			'xocodexyaml' => array(
				'parent' => $xocodex,
				'title'  => __( 'YAML: CSS Framework', 'xtreme-one-toolbar' ),
				'href'   => 'http://www.yaml.de/docs/index.html',
				'meta'   => array( 'title' => __( 'YAML: CSS Framework', 'xtreme-one-toolbar' ) )
			),

			// Xtreme One HQ menu items
			'xosites' => array(
				'parent' => $xogroup,
				'title'  => __( 'Xtreme One HQ', 'xtreme-one-toolbar' ),
				'href'   => $xo_url_home,
				'meta'   => array( 'title' => __( 'Xtreme One HQ', 'xtreme-one-toolbar' ) )
			),
			'xoblog' => array(
				'parent' => $xosites,
				'title'  => __( 'Official Blog', 'xtreme-one-toolbar' ),
				'href'   => $xo_url_blog,
				'meta'   => array( 'title' => __( 'Official Blog', 'xtreme-one-toolbar' ) )
			),
			'xofeatures' => array(
				'parent' => $xosites,
				'title'  => __( 'Framework Features', 'xtreme-one-toolbar' ),
				'href'   => $xo_url_features,
				'meta'   => array( 'title' => __( 'Framework Features', 'xtreme-one-toolbar' ) )
			),
			'xothemes' => array(
				'parent' => $xosites,
				'title'  => __( 'Official Child Themes', 'xtreme-one-toolbar' ),
				'href'   => $xo_url_themes,
				'meta'   => array( 'title' => __( 'Official Child Themes', 'xtreme-one-toolbar' ) )
			),
			'xovideos' => array(
				'parent' => $xosites,
				'title'  => __( 'Videos', 'xtreme-one-toolbar' ),
				'href'   => $xo_url_videos,
				'meta'   => array( 'title' => __( 'Videos', 'xtreme-one-toolbar' ) )
			),
			'xoshowcase' => array(
				'parent' => $xosites,
				'title'  => __( 'Showcase', 'xtreme-one-toolbar' ),
				'href'   => $xo_url_showcase,
				'meta'   => array( 'title' => __( 'Showcase', 'xtreme-one-toolbar' ) )
			),
			'xoaffiliates' => array(
				'parent' => $xosites,
				'title'  => __( 'Affiliate Program', 'xtreme-one-toolbar' ),
				'href'   => $xo_url_affiliates,
				'meta'   => array( 'title' => __( 'Affiliate Program', 'xtreme-one-toolbar' ) )
			),
			'xoaffiliateslogin' => array(
				'parent' => $xoaffiliates,
				'title'  => __( 'Affiliate Login', 'xtreme-one-toolbar' ),
				'href'   => 'https://secure.avangate.com/affiliates/',
				'meta'   => array( 'title' => __( 'Affiliate Login', 'xtreme-one-toolbar' ) )
			),
			'xotwitter' => array(
				'parent' => $xosites,
				'title'  => __( 'Twitter Channel', 'xtreme-one-toolbar' ),
				'href'   => 'http://twitter.com/#!/xtremetheme',
				'meta'   => array( 'title' => __( 'Twitter Channel', 'xtreme-one-toolbar' ) )
			),
			'xofacebook' => array(
				'parent' => $xosites,
				'title'  => __( 'Facebook Page', 'xtreme-one-toolbar' ),
				'href'   => 'http://facebook.com/xtremetheme',
				'meta'   => array( 'title' => __( 'Facebook Page', 'xtreme-one-toolbar' ) )
			),
			'xopluginswporg' => array(
				'parent' => $xosites,
				'title'  => __( 'Free plugins/extensions at WP.org', 'xtreme-one-toolbar' ),
				'href'   => 'http://wordpress.org/extend/plugins/search.php?q=xtreme+one',
				'meta'   => array( 'title' => __( 'Free plugins/extensions at WP.org', 'xtreme-one-toolbar' ) )
			),
		);

	}  // end-if constant check for displaying resources


	/** Display language specific links only for these locales: de_DE, de_AT, de_CH, de_LU */
	if ( ! defined( 'XOTB_DE_DISPLAY' ) && ( get_locale() == 'de_DE' || get_locale() == 'de_AT' || get_locale() == 'de_CH' || get_locale() == 'de_LU' ) ) {
		// German Xtreme One language packs
		$xogroup_menu_items['xo-languages-de'] = array(
			'parent' => $xogroup,
			'title'  => __( 'German language files', 'xtreme-one-toolbar' ),
			'href'   => 'http://deckerweb.de/material/sprachdateien/xtreme-one-framework/',
			'meta'   => array( 'title' => __( 'German language files for Xtreme One Framework and more extensions', 'xtreme-one-toolbar' ) )
		);
	}  // end-if German locales


	/** Show these items only if Xtreme One Framework is actually installed */
	if ( ( defined( 'XF_THEME_DIR' ) || get_template() == 'xtreme-one' ) && current_user_can( 'manage_options' ) ) {

		// XO Settings section
		$menu_items['xosettings'] = array(
			'parent' => $xobar,
			'title'  => __( 'Framework Settings', 'xtreme-one-toolbar' ),
			'href'   => admin_url( 'themes.php?page=xtreme_backend' ),
			'meta'   => array( 'target' => '', 'title' => _x( 'Framework Settings: Main Configuration', 'Translators: For the tooltip', 'xtreme-one-toolbar' ) )
		);

		// XO Layouts section
		$menu_items['xolayouts'] = array(
			'parent' => $xobar,
			'title'  => __( 'Layout Manager', 'xtreme-one-toolbar' ),
			'href'   => admin_url( 'themes.php?page=xtreme_layouts' ),
			'meta'   => array( 'target' => '', 'title' => __( 'Layout Manager', 'xtreme-one-toolbar' ) )
		);
		$menu_items['xol-add'] = array(
			'parent' => $xolayouts,
			'title'  => __( 'Add new Layout', 'xtreme-one-toolbar' ),
			'href'   => admin_url( 'themes.php?page=xtreme_layouts&mode=add_layout' ),
			'meta'   => array( 'target' => '', 'title' => __( 'Add new Layout', 'xtreme-one-toolbar' ) )
		);

		// XO Widgets section
		if ( current_user_can( 'edit_theme_options' ) ) {
			$menu_items['xowidgets'] = array(
				'parent' => $xobar,
				'title'  => $xotb_xtreme_name . ' ' . __( 'Widgets', 'xtreme-one-toolbar' ),
				'href'   => admin_url( 'widgets.php' ),
				'meta'   => array( 'target' => '', 'title' => $xotb_xtreme_name_tooltip . ' ' . __( 'Widgets', 'xtreme-one-toolbar' ) )
			);
		}  // end-if cap check

		$menu_items['xowidgets-settings'] = array(
			'parent' => $xobar,
			'title'  => $xotb_xtreme_name . ' ' . __( 'Widget Config', 'xtreme-one-toolbar' ),
			'href'   => admin_url( 'options-general.php?page=xtreme_widgets' ),
			'meta'   => array( 'target' => '', 'title' => $xotb_xtreme_name_tooltip . ' ' . __( 'Widget Config', 'xtreme-one-toolbar' ) )
		);

		// XO Backup/Export/Import section
		$menu_items['xobackup'] = array(
			'parent' => $xobar,
			'title'  => __( 'Backup - Export/Import', 'xtreme-one-toolbar' ),
			'href'   => admin_url( 'themes.php?page=xtreme_backup' ),
			'meta'   => array( 'target' => '', 'title' => __( 'Backup - Export/Import', 'xtreme-one-toolbar' ) )
		);

		/**
		 * Display last main item in the menu for active extensions/plugins
		 * ATTENTION: This is where plugins/extensions hook in on the sub-level hierarchy
		 *
		 * @since 1.0
		 * @version 1.1
		 */
		if ( ! defined( 'XOTB_EXTENSIONS_DISPLAY' ) && current_user_can( 'activate_plugins' ) ) {
			$menu_items['extensions'] = array(
				'parent' => $pgroup,
				'title'  => __( 'Active Extensions', 'xtreme-one-toolbar' ),
				'href'   => is_network_admin() ? network_admin_url( 'plugins.php' ) : admin_url( 'plugins.php' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Active Extensions', 'xtreme-one-toolbar' ) )
			);
		}  // end-if constant & cap check for displaying extensions

	} else {

		// If Xtreme One is not active, to avoid PHP notices
		$menu_items = $xogroup_menu_items;

	}  // end-if XO conditional


	/**
	 * Display links to active Xtreme One Child Themes settings' pages
	 *
	 * @since 1.1
	 */
		/** Include plugin file with theme support links */
		require_once( XOTB_PLUGIN_DIR . '/includes/xotb-themes.php' );


	/**
	 * Display links to active Xtreme One plugins/extensions settings' pages
	 *
	 * @since 1.1
	 */
		/** Include plugin file with plugin support links */
		require_once( XOTB_PLUGIN_DIR . '/includes/xotb-plugins.php' );


	/** Allow menu items to be filtered, but pass in parent menu item IDs */
	$menu_items = (array) apply_filters( 'ddw_xotb_menu_items', $menu_items, $xogroup_menu_items, $prefix, $xobar, 
						$xosupport, $xocodex, $xosites, $xosettings, $xolayouts, 
						$extgroup, $tgroup, $xochildsettings, $pgroup, $extensions, $extwpseosm, $extyoastseo, 
						$extseoultimate, $extgdhs, $xogroup );


	/**
	 * Add the Xtreme One top-level menu item
	 *
	 * @since 1.0
	 * @version 1.1
	 *
	 * @param $xotb_main_item_title
	 * @param $xotb_main_item_title_tooltip
	 * @param $xotb_main_item_icon_display
	 */
		/** Filter the main item name */
		$xotb_main_item_title = apply_filters( 'xotb_filter_main_item', __( 'Xtreme One', 'xtreme-one-toolbar' ) );

		/** Filter the main item name's tooltip */
		$xotb_main_item_title_tooltip = apply_filters( 'xotb_filter_main_item_tooltip', _x( 'Xtreme One Framework', 'Translators: For the tooltip', 'xtreme-one-toolbar' ) );

		/** Filter the main item icon's class/display */
		$xotb_main_item_icon_display = apply_filters( 'xotb_filter_main_item_icon_display', 'icon-xtreme' );

		$wp_admin_bar->add_menu( array(
			'id'    => $xobar,
			'title' => $xotb_main_item_title,
			'href'  => admin_url( 'themes.php?page=xtreme_backend' ),
			'meta'  => array( 'class' => $xotb_main_item_icon_display, 'title' => $xotb_main_item_title_tooltip )
		) );


	/** Loop through the menu items */
	foreach ( $menu_items as $id => $menu_item ) {
		
		// Add in the item ID
		$menu_item['id'] = $prefix . $id;

		// Add meta target to each item where it's not already set, so links open in new window/tab
		if ( ! isset( $menu_item['meta']['target'] ) )		
			$menu_item['meta']['target'] = '_blank';

		// Add class to links that open up in a new window/tab
		if ( '_blank' === $menu_item['meta']['target'] ) {
			if ( ! isset( $menu_item['meta']['class'] ) )
				$menu_item['meta']['class'] = '';
			$menu_item['meta']['class'] .= $prefix . 'xotb-new-tab';
		}

		// Add item
		$wp_admin_bar->add_menu( $menu_item );

	}  // end foreach menu items


	/**
	 * Action Hook 'xotb_custom_main_items'
	 * allows for hooking other main items in
	 *
	 * @since 1.1
	 */
	do_action( 'xotb_custom_main_items' );


	/** Extend Group: Main Entry */
	$wp_admin_bar->add_group( array(
		'parent' => $xobar,
		'id'     => $extgroup,
	) );

		/** Theme Group: Main Entry */
		if ( !defined( 'XOTB_THEME_DISPLAY' ) ) {
			$wp_admin_bar->add_group( array(
				'parent' => $extgroup,
				'id'     => $tgroup,
			) );
		}  // end-if constant check for displaying theme group

		/** Plugin Group: Main Entry */
		$wp_admin_bar->add_group( array(
			'parent' => $extgroup,
			'id'     => $pgroup,
		) );


	/** XO Group: Main Entry */
	$wp_admin_bar->add_group( array(
		'parent' => $xobar,
		'id'     => $xogroup,
		'meta'   => array( 'class' => 'ab-sub-secondary' )
	) );

	/** XO Group: Loop through the group menu items */
	foreach ( $xogroup_menu_items as $id => $xogroup_menu_item ) {
		
		// XO Group: Add in the item ID
		$xogroup_menu_item['id'] = $prefix . $id;

		// XO Group: Add meta target to each item where it's not already set, so links open in new window/tab
		if ( ! isset( $xogroup_menu_item['meta']['target'] ) )		
			$xogroup_menu_item['meta']['target'] = '_blank';

		// XO Group: Add class to links that open up in a new window/tab
		if ( '_blank' === $xogroup_menu_item['meta']['target'] ) {
			if ( ! isset( $xogroup_menu_item['meta']['class'] ) )
				$xogroup_menu_item['meta']['class'] = '';
			$xogroup_menu_item['meta']['class'] .= $prefix . 'xotb-new-tab';
		}

		// XO Group: Add item
		$wp_admin_bar->add_menu( $xogroup_menu_item );

	}  // end foreach XO Group


	/**
	 * Action Hook 'xotb_custom_group_items'
	 * allows for hooking other XO Group items in
	 *
	 * @since 1.1
	 */
	do_action( 'xotb_custom_group_items' );

}  // end of main function ddw_xotb_admin_bar_menu


add_action( 'wp_head', 'ddw_xotb_admin_style' );
add_action( 'admin_head', 'ddw_xotb_admin_style' );
/**
 * Add the styles for new WordPress Toolbar / Admin Bar entry
 * 
 * @since 1.0
 * @version 1.1
 */
function ddw_xotb_admin_style() {

	/** No styles if admin bar is disabled or user is not logged in */
	if ( ! is_admin_bar_showing() || ! is_user_logged_in() )
		return;

	/** Add CSS styles to wp_head/admin_head */
	$xotb_main_icon = apply_filters( 'xotb_filter_main_icon', plugins_url( 'xtreme-one-toolbar/images/icon-xtreme.png',
dirname( __FILE__ ) ) );

	?>
	<style type="text/css">
		#wpadminbar.nojs .ab-top-menu > li.menupop.icon-xtreme:hover > .ab-item,
		#wpadminbar .ab-top-menu > li.menupop.icon-xtreme.hover > .ab-item,
		#wpadminbar.nojs .ab-top-menu > li.menupop.icon-xtreme > .ab-item,
		#wpadminbar .ab-top-menu > li.menupop.icon-xtreme > .ab-item {
      			background-image: url(<?php echo $xotb_main_icon; ?>);
			background-repeat: no-repeat;
			background-position: 0.85em 50%;
			padding-left: 30px;
		}
		#wp-admin-bar-ddw-xtreme-xo-languages-de > .ab-item:before {
			color: #ff9900;
			content: '• ';
		}
		#wp-admin-bar-ddw-xtreme-extwpseosm > .ab-item {
			min-width: 60px !important;
		}
	</style>
	<?php

}  // end of function ddw_xotb_admin_style


/**
 * Helper functions for custom branding of the plugin
 *
 * @since 1.1
 */
	/** Include plugin file with special custom stuff */
	require_once( XOTB_PLUGIN_DIR . '/includes/xotb-branding.php' );
